/*   GTimeTracker - a time tracker
 *   Copyright (C) 1997,98 Eckehard Berns
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <config.h>
#include <gnome.h>
#include <string.h>

#include "ctree.h"
#include "cur-proj.h"
#include "gtt.h"
#include "proj.h"


static gint main_timer = 0;

static gint 
timer_func(gpointer data)
{
	log_proj(cur_proj);
	if (!cur_proj) return 1;

	gtt_project_timer_update (cur_proj);
	if (config_show_secs) 
	{
		ctree_update_label(cur_proj);
	} 
	else if (0 == gtt_project_total_secs_day(cur_proj)) 
	{
		ctree_update_label(cur_proj);
	}
	return 1;
}


void menu_timer_state(int);

void start_timer(void)
{
	if (main_timer) return;
	log_proj(cur_proj);
	gtt_project_timer_start (cur_proj);

	/* the timer is measured in milliseconds, so 1000
         * means it pops once a second. */
	main_timer = gtk_timeout_add(1000, timer_func, NULL);
	update_status_bar();
}



void stop_timer(void)
{
	if (!main_timer) return;
	log_proj(NULL);
	gtt_project_timer_stop (cur_proj);
	gtk_timeout_remove(main_timer);
	main_timer = 0;
	update_status_bar();
}

gboolean 
timer_is_running (void)
{
	return (0 != main_timer);
}
